@@ -21,9 +21,11 @@
  *         David Zeuthen <davidz@redhat.com>
  */
 
-#include <config.h>
+#include "config.h"
 #include "gdrive.h"
 #include "gsimpleasyncresult.h"
+#include "gasyncresult.h"
+#include "gioerror.h"
 #include "glibintl.h"
 
 #include "gioalias.h"
@@ -59,11 +61,11 @@ static void g_drive_class_init (gpointer g_class,
 GType
 g_drive_get_type (void)
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static GType drive_type = 0;
 
-  if (g_once_init_enter (&g_define_type_id__volatile))
+  if (! drive_type)
     {
-      const GTypeInfo drive_info =
+      static const GTypeInfo drive_info =
       {
         sizeof (GDriveIface), /* class_size */
 	g_drive_base_init,   /* base_init */
@@ -75,16 +77,15 @@ g_drive_get_type (void)
 	0,              /* n_preallocs */
 	NULL
       };
-      GType g_define_type_id =
+
+      drive_type =
 	g_type_register_static (G_TYPE_INTERFACE, I_("GDrive"),
 				&drive_info, 0);
 
-      g_type_interface_add_prerequisite (g_define_type_id, G_TYPE_OBJECT);
-
-      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
+      g_type_interface_add_prerequisite (drive_type, G_TYPE_OBJECT);
     }
 
-  return g_define_type_id__volatile;
+  return drive_type;
 }
 
 static void
