@@ -20,7 +20,7 @@
  * Author: Alexander Larsson <alexl@redhat.com>
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -35,6 +35,7 @@
 #include <glib/gstdio.h>
 #include "glibintl.h"
 #include "gioerror.h"
+#include "gcancellable.h"
 #include "glocalfileoutputstream.h"
 #include "glocalfileinfo.h"
 
@@ -48,6 +49,10 @@
 #endif
 #endif
 
+#ifndef O_BINARY
+#define O_BINARY 0
+#endif
+
 #include "gioalias.h"
 
 #define g_local_file_output_stream_get_type _g_local_file_output_stream_get_type
@@ -104,9 +109,8 @@ g_local_file_output_stream_finalize (GObject *object)
   g_free (file->priv->original_filename);
   g_free (file->priv->backup_filename);
   g_free (file->priv->etag);
-  
-  if (G_OBJECT_CLASS (g_local_file_output_stream_parent_class)->finalize)
-    (*G_OBJECT_CLASS (g_local_file_output_stream_parent_class)->finalize) (object);
+
+  G_OBJECT_CLASS (g_local_file_output_stream_parent_class)->finalize (object);
 }
 
 static void
@@ -158,13 +162,15 @@ g_local_file_output_stream_write (GOutputStream  *stream,
       res = write (file->priv->fd, buffer, count);
       if (res == -1)
 	{
-	  if (errno == EINTR)
+          int errsv = errno;
+
+	  if (errsv == EINTR)
 	    continue;
 	  
 	  g_set_error (error, G_IO_ERROR,
-		       g_io_error_from_errno (errno),
+		       g_io_error_from_errno (errsv),
 		       _("Error writing to file: %s"),
-		       g_strerror (errno));
+		       g_strerror (errsv));
 	}
       
       break;
@@ -197,32 +203,42 @@ g_local_file_output_stream_close (GOutputStream  *stream,
 	  
 #ifdef HAVE_LINK
 	  /* create original -> backup link, the original is then renamed over */
-	  if (unlink (file->priv->backup_filename) != 0 &&
+	  if (g_unlink (file->priv->backup_filename) != 0 &&
 	      errno != ENOENT)
 	    {
+              int errsv = errno;
+
 	      g_set_error (error, G_IO_ERROR,
 			   G_IO_ERROR_CANT_CREATE_BACKUP,
 			   _("Error removing old backup link: %s"),
-			   g_strerror (errno));
+			   g_strerror (errsv));
 	      goto err_out;
 	    }
 
 	  if (link (file->priv->original_filename, file->priv->backup_filename) != 0)
 	    {
-	      g_set_error (error, G_IO_ERROR,
-			   G_IO_ERROR_CANT_CREATE_BACKUP,
-			   _("Error creating backup link: %s"),
-			   g_strerror (errno));
-	      goto err_out;
+	      /*  link failed or is not supported, try rename  */
+	      if (g_rename (file->priv->original_filename, file->priv->backup_filename) != 0)
+		{
+                  int errsv = errno;
+
+	    	  g_set_error (error, G_IO_ERROR,
+		    	       G_IO_ERROR_CANT_CREATE_BACKUP,
+			       _("Error creating backup copy: %s"),
+			       g_strerror (errsv));
+	          goto err_out;
+		}
 	    }
 #else
 	    /* If link not supported, just rename... */
-	  if (!rename (file->priv->original_filename, file->priv->backup_filename) != 0)
+	  if (g_rename (file->priv->original_filename, file->priv->backup_filename) != 0)
 	    {
+              int errsv = errno;
+
 	      g_set_error (error, G_IO_ERROR,
 			   G_IO_ERROR_CANT_CREATE_BACKUP,
 			   _("Error creating backup copy: %s"),
-			   g_strerror (errno));
+			   g_strerror (errsv));
 	      goto err_out;
 	    }
 #endif
@@ -233,12 +249,14 @@ g_local_file_output_stream_close (GOutputStream  *stream,
 	goto err_out;
 
       /* tmp -> original */
-      if (rename (file->priv->tmp_filename, file->priv->original_filename) != 0)
+      if (g_rename (file->priv->tmp_filename, file->priv->original_filename) != 0)
 	{
+          int errsv = errno;
+
 	  g_set_error (error, G_IO_ERROR,
 		       g_io_error_from_errno (errno),
 		       _("Error renaming temporary file: %s"),
-		       g_strerror (errno));
+		       g_strerror (errsv));
 	  goto err_out;
 	}
     }
@@ -254,10 +272,12 @@ g_local_file_output_stream_close (GOutputStream  *stream,
       res = close (file->priv->fd);
       if (res == -1)
 	{
+          int errsv = errno;
+
 	  g_set_error (error, G_IO_ERROR,
-		       g_io_error_from_errno (errno),
+		       g_io_error_from_errno (errsv),
 		       _("Error closing file: %s"),
-		       g_strerror (errno));
+		       g_strerror (errsv));
 	}
       break;
     }
@@ -306,8 +326,7 @@ g_local_file_output_stream_can_seek (GFileOutputStream *stream)
   
   pos = lseek (file->priv->fd, 0, SEEK_CUR);
 
-  if (pos == (off_t)-1 &&
-      errno == ESPIPE)
+  if (pos == (off_t)-1 && errno == ESPIPE)
     return FALSE;
   
   return TRUE;
@@ -346,10 +365,12 @@ g_local_file_output_stream_seek (GFileOutputStream  *stream,
 
   if (pos == (off_t)-1)
     {
+      int errsv = errno;
+
       g_set_error (error, G_IO_ERROR,
-		   g_io_error_from_errno (errno),
+		   g_io_error_from_errno (errsv),
 		   _("Error seeking in file: %s"),
-		   g_strerror (errno));
+		   g_strerror (errsv));
       return FALSE;
     }
   
@@ -383,7 +404,9 @@ g_local_file_output_stream_truncate (GFileOutputStream  *stream,
   
   if (res == -1)
     {
-      if (errno == EINTR)
+      int errsv = errno;
+
+      if (errsv == EINTR)
 	{
 	  if (g_cancellable_set_error_if_cancelled (cancellable, error))
 	    return FALSE;
@@ -391,9 +414,9 @@ g_local_file_output_stream_truncate (GFileOutputStream  *stream,
 	}
 
       g_set_error (error, G_IO_ERROR,
-		   g_io_error_from_errno (errno),
+		   g_io_error_from_errno (errsv),
 		   _("Error truncating file: %s"),
-		   g_strerror (errno));
+		   g_strerror (errsv));
       return FALSE;
     }
   
@@ -437,23 +460,25 @@ _g_local_file_output_stream_create  (const char        *filename,
   else
     mode = 0666;
   
-  fd = g_open (filename,
-	       O_CREAT | O_EXCL | O_WRONLY,
-	       0666);
+  fd = g_open (filename, O_CREAT | O_EXCL | O_WRONLY | O_BINARY, mode);
   if (fd == -1)
     {
       int errsv = errno;
 
       if (errsv == EINVAL)
 	/* This must be an invalid filename, on e.g. FAT */
-	g_set_error (error, G_IO_ERROR,
-		     G_IO_ERROR_INVALID_FILENAME,
-		     _("Invalid filename"));
+	g_set_error_literal (error, G_IO_ERROR,
+                             G_IO_ERROR_INVALID_FILENAME,
+                             _("Invalid filename"));
       else
-	g_set_error (error, G_IO_ERROR,
-		     g_io_error_from_errno (errsv),
-		     _("Error opening file '%s': %s"),
-		     filename, g_strerror (errsv));
+	{
+	  char *display_name = g_filename_display_name (filename);
+	  g_set_error (error, G_IO_ERROR,
+		       g_io_error_from_errno (errsv),
+		       _("Error opening file '%s': %s"),
+		       display_name, g_strerror (errsv));
+	  g_free (display_name);
+	}
       return NULL;
     }
   
@@ -480,23 +505,25 @@ _g_local_file_output_stream_append  (const char        *filename,
   else
     mode = 0666;
 
-  fd = g_open (filename,
-	       O_CREAT | O_APPEND | O_WRONLY,
-	       mode);
+  fd = g_open (filename, O_CREAT | O_APPEND | O_WRONLY | O_BINARY, mode);
   if (fd == -1)
     {
       int errsv = errno;
 
       if (errsv == EINVAL)
 	/* This must be an invalid filename, on e.g. FAT */
-	g_set_error (error, G_IO_ERROR,
-		     G_IO_ERROR_INVALID_FILENAME,
-		     _("Invalid filename"));
+	g_set_error_literal (error, G_IO_ERROR,
+                             G_IO_ERROR_INVALID_FILENAME,
+                             _("Invalid filename"));
       else
-	g_set_error (error, G_IO_ERROR,
-		     g_io_error_from_errno (errsv),
-		     _("Error opening file '%s': %s"),
-		     filename, g_strerror (errsv));
+	{
+	  char *display_name = g_filename_display_name (filename);
+	  g_set_error (error, G_IO_ERROR,
+		       g_io_error_from_errno (errsv),
+		       _("Error opening file '%s': %s"),
+		       display_name, g_strerror (errsv));
+	  g_free (display_name);
+	}
       return NULL;
     }
   
@@ -533,13 +560,15 @@ copy_file_data (gint     sfd,
       bytes_read = read (sfd, buffer, BUFSIZE);
       if (bytes_read == -1)
 	{
-	  if (errno == EINTR)
+          int errsv = errno;
+
+	  if (errsv == EINTR)
 	    continue;
 	  
 	  g_set_error (error, G_IO_ERROR,
-		       g_io_error_from_errno (errno),
+		       g_io_error_from_errno (errsv),
 		       _("Error reading from file: %s"),
-		       g_strerror (errno));
+		       g_strerror (errsv));
 	  ret = FALSE;
 	  break;
 	}
@@ -552,13 +581,15 @@ copy_file_data (gint     sfd,
 	  bytes_written = write (dfd, write_buffer, bytes_to_write);
 	  if (bytes_written == -1)
 	    {
-	      if (errno == EINTR)
+              int errsv = errno;
+
+	      if (errsv == EINTR)
 		continue;
 	      
 	      g_set_error (error, G_IO_ERROR,
-			   g_io_error_from_errno (errno),
+			   g_io_error_from_errno (errsv),
 			   _("Error writing to file: %s"),
-			   g_strerror (errno));
+			   g_strerror (errsv));
 	      ret = FALSE;
 	      break;
 	    }
@@ -592,9 +623,9 @@ handle_overwrite_open (const char    *filename,
   /* We only need read access to the original file if we are creating a backup.
    * We also add O_CREATE to avoid a race if the file was just removed */
   if (create_backup)
-    open_flags = O_RDWR | O_CREAT;
+    open_flags = O_RDWR | O_CREAT | O_BINARY;
   else
-    open_flags = O_WRONLY | O_CREAT;
+    open_flags = O_WRONLY | O_CREAT | O_BINARY;
   
   /* Some systems have O_NOFOLLOW, which lets us avoid some races
    * when finding out if the file we opened was a symlink */
@@ -616,19 +647,25 @@ handle_overwrite_open (const char    *filename,
     
   if (fd == -1)
     {
+      int errsv = errno;
+      char *display_name = g_filename_display_name (filename);
       g_set_error (error, G_IO_ERROR,
-		   g_io_error_from_errno (errno),
+		   g_io_error_from_errno (errsv),
 		   _("Error opening file '%s': %s"),
-		   filename, g_strerror (errno));
+		   display_name, g_strerror (errsv));
+      g_free (display_name);
       return -1;
     }
   
   if (fstat (fd, &original_stat) != 0) 
     {
+      int errsv = errno;
+      char *display_name = g_filename_display_name (filename);
       g_set_error (error, G_IO_ERROR,
-		   g_io_error_from_errno (errno),
+		   g_io_error_from_errno (errsv),
 		   _("Error stating file '%s': %s"),
-		   filename, g_strerror (errno));
+		   display_name, g_strerror (errsv));
+      g_free (display_name);
       goto err_out;
     }
   
@@ -636,15 +673,15 @@ handle_overwrite_open (const char    *filename,
   if (!S_ISREG (original_stat.st_mode))
     {
       if (S_ISDIR (original_stat.st_mode))
-	g_set_error (error,
-		     G_IO_ERROR,
-		     G_IO_ERROR_IS_DIRECTORY,
-		     _("Target file is a directory"));
+	g_set_error_literal (error,
+                             G_IO_ERROR,
+                             G_IO_ERROR_IS_DIRECTORY,
+                             _("Target file is a directory"));
       else
-	g_set_error (error,
-		     G_IO_ERROR,
-		     G_IO_ERROR_NOT_REGULAR_FILE,
-		     _("Target file is not a regular file"));
+	g_set_error_literal (error,
+                             G_IO_ERROR,
+                             G_IO_ERROR_NOT_REGULAR_FILE,
+                             _("Target file is not a regular file"));
       goto err_out;
     }
   
@@ -653,10 +690,10 @@ handle_overwrite_open (const char    *filename,
       current_etag = _g_local_file_info_create_etag (&original_stat);
       if (strcmp (etag, current_etag) != 0)
 	{
-	  g_set_error (error,
-		       G_IO_ERROR,
-		       G_IO_ERROR_WRONG_ETAG,
-		       _("The file was externally modified"));
+	  g_set_error_literal (error,
+                               G_IO_ERROR,
+                               G_IO_ERROR_WRONG_ETAG,
+                               _("The file was externally modified"));
 	  g_free (current_etag);
 	  goto err_out;
 	}
@@ -693,10 +730,10 @@ handle_overwrite_open (const char    *filename,
       /* try to keep permissions */
 
       if (
-#ifdef F_CHOWN
+#ifdef HAVE_FCHOWN
 	  fchown (tmpfd, original_stat.st_uid, original_stat.st_gid) == -1 ||
 #endif
-#ifdef F_CHMOD
+#ifdef HAVE_FCHMOD
 	  fchmod (tmpfd, original_stat.st_mode) == -1 ||
 #endif
 	  0
@@ -711,7 +748,7 @@ handle_overwrite_open (const char    *filename,
 	      original_stat.st_mode != tmp_statbuf.st_mode)
 	    {
 	      close (tmpfd);
-	      unlink (tmp_filename);
+	      g_unlink (tmp_filename);
 	      g_free (tmp_filename);
 	      goto fallback_strategy;
 	    }
@@ -732,26 +769,26 @@ handle_overwrite_open (const char    *filename,
       
       backup_filename = create_backup_filename (filename);
 
-      if (unlink (backup_filename) == -1 && errno != ENOENT)
+      if (g_unlink (backup_filename) == -1 && errno != ENOENT)
 	{
-	  g_set_error (error,
-		       G_IO_ERROR,
-		       G_IO_ERROR_CANT_CREATE_BACKUP,
-		       _("Backup file creation failed"));
+	  g_set_error_literal (error,
+                               G_IO_ERROR,
+                               G_IO_ERROR_CANT_CREATE_BACKUP,
+                               _("Backup file creation failed"));
 	  g_free (backup_filename);
 	  goto err_out;
 	}
 
       bfd = g_open (backup_filename,
-		    O_WRONLY | O_CREAT | O_EXCL,
+		    O_WRONLY | O_CREAT | O_EXCL | O_BINARY,
 		    original_stat.st_mode & 0777);
 
       if (bfd == -1)
 	{
-	  g_set_error (error,
-		       G_IO_ERROR,
-		       G_IO_ERROR_CANT_CREATE_BACKUP,
-		       _("Backup file creation failed"));
+	  g_set_error_literal (error,
+                               G_IO_ERROR,
+                               G_IO_ERROR_CANT_CREATE_BACKUP,
+                               _("Backup file creation failed"));
 	  g_free (backup_filename);
 	  goto err_out;
 	}
@@ -760,14 +797,14 @@ handle_overwrite_open (const char    *filename,
        * original file. If this fails, set the protection
        * bits for the group same as the protection bits for
        * others. */
-#ifdef HAVE_FCHOWN
+#if defined(HAVE_FCHOWN) && defined(HAVE_FCHMOD)
       if (fstat (bfd, &tmp_statbuf) != 0)
 	{
-	  g_set_error (error,
-		       G_IO_ERROR,
-		       G_IO_ERROR_CANT_CREATE_BACKUP,
-		       _("Backup file creation failed"));
-	  unlink (backup_filename);
+	  g_set_error_literal (error,
+                               G_IO_ERROR,
+                               G_IO_ERROR_CANT_CREATE_BACKUP,
+                               _("Backup file creation failed"));
+	  g_unlink (backup_filename);
 	  g_free (backup_filename);
 	  goto err_out;
 	}
@@ -779,11 +816,11 @@ handle_overwrite_open (const char    *filename,
 		      (original_stat.st_mode & 0707) |
 		      ((original_stat.st_mode & 07) << 3)) != 0)
 	    {
-	      g_set_error (error,
-			   G_IO_ERROR,
-			   G_IO_ERROR_CANT_CREATE_BACKUP,
-			   _("Backup file creation failed"));
-	      unlink (backup_filename);
+	      g_set_error_literal (error,
+                                   G_IO_ERROR,
+                                   G_IO_ERROR_CANT_CREATE_BACKUP,
+                                   _("Backup file creation failed"));
+	      g_unlink (backup_filename);
 	      close (bfd);
 	      g_free (backup_filename);
 	      goto err_out;
@@ -793,11 +830,11 @@ handle_overwrite_open (const char    *filename,
 
       if (!copy_file_data (fd, bfd, NULL))
 	{
-	  g_set_error (error,
-		       G_IO_ERROR,
-		       G_IO_ERROR_CANT_CREATE_BACKUP,
-		       _("Backup file creation failed"));
-	  unlink (backup_filename);
+	  g_set_error_literal (error,
+                               G_IO_ERROR,
+                               G_IO_ERROR_CANT_CREATE_BACKUP,
+                               _("Backup file creation failed"));
+	  g_unlink (backup_filename);
 	  close (bfd);
 	  g_free (backup_filename);
 	  
@@ -810,10 +847,12 @@ handle_overwrite_open (const char    *filename,
       /* Seek back to the start of the file after the backup copy */
       if (lseek (fd, 0, SEEK_SET) == -1)
 	{
+          int errsv = errno;
+
 	  g_set_error (error, G_IO_ERROR,
-		       g_io_error_from_errno (errno),
+		       g_io_error_from_errno (errsv),
 		       _("Error seeking in file: %s"),
-		       g_strerror (errno));
+		       g_strerror (errsv));
 	  goto err_out;
 	}
     }
@@ -825,10 +864,12 @@ handle_overwrite_open (const char    *filename,
   if (ftruncate (fd, 0) == -1)
 #endif
     {
+      int errsv = errno;
+
       g_set_error (error, G_IO_ERROR,
-		   g_io_error_from_errno (errno),
+		   g_io_error_from_errno (errsv),
 		   _("Error truncating file: %s"),
-		   g_strerror (errno));
+		   g_strerror (errsv));
       goto err_out;
     }
     
@@ -863,9 +904,7 @@ _g_local_file_output_stream_replace (const char        *filename,
     mode = 0666;
 
   /* If the file doesn't exist, create it */
-  fd = g_open (filename,
-	       O_CREAT | O_EXCL | O_WRONLY,
-	       mode);
+  fd = g_open (filename, O_CREAT | O_EXCL | O_WRONLY | O_BINARY, mode);
 
   if (fd == -1 && errno == EEXIST)
     {
@@ -881,14 +920,18 @@ _g_local_file_output_stream_replace (const char        *filename,
 
       if (errsv == EINVAL)
 	/* This must be an invalid filename, on e.g. FAT */
-	g_set_error (error, G_IO_ERROR,
-		     G_IO_ERROR_INVALID_FILENAME,
-		     _("Invalid filename"));
+	g_set_error_literal (error, G_IO_ERROR,
+                             G_IO_ERROR_INVALID_FILENAME,
+                             _("Invalid filename"));
       else
-	g_set_error (error, G_IO_ERROR,
-		     g_io_error_from_errno (errsv),
-		     _("Error opening file '%s': %s"),
-		     filename, g_strerror (errsv));
+	{
+	  char *display_name = g_filename_display_name (filename);
+	  g_set_error (error, G_IO_ERROR,
+		       g_io_error_from_errno (errsv),
+		       _("Error opening file '%s': %s"),
+		       display_name, g_strerror (errsv));
+	  g_free (display_name);
+	}
       return NULL;
     }
   
