@@ -23,7 +23,7 @@
  *         David Zeuthen <davidz@redhat.com>
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <string.h>
 
@@ -32,7 +32,9 @@
 #include "gunixmounts.h"
 #include "gunixmount.h"
 #include "gunixvolume.h"
+#include "gmount.h"
 #include "gmountprivate.h"
+#include "giomodule.h"
 #include "glibintl.h"
 
 #include "gioalias.h"
@@ -84,9 +86,8 @@ g_unix_volume_monitor_finalize (GObject *object)
   g_list_free (monitor->volumes);
   g_list_foreach (monitor->mounts, (GFunc)g_object_unref, NULL);
   g_list_free (monitor->mounts);
-  
-  if (G_OBJECT_CLASS (g_unix_volume_monitor_parent_class)->finalize)
-    (*G_OBJECT_CLASS (g_unix_volume_monitor_parent_class)->finalize) (object);
+
+  G_OBJECT_CLASS (g_unix_volume_monitor_parent_class)->finalize (object);
 }
 
 static GList *
@@ -149,15 +150,10 @@ get_mount_for_mount_path (const char *mount_path,
   GUnixMount *mount;
 
   mount_entry = g_unix_mount_at (mount_path, NULL);
-
-  if (!mount_entry)
-    return NULL;
-
+  
   /* TODO: Set mountable volume? */
   mount = _g_unix_mount_new (NULL, mount_entry, NULL);
 
-  g_unix_mount_free (mount_entry);
-
   return G_MOUNT (mount);
 }
 
