@@ -21,10 +21,12 @@
  *         David Zeuthen <davidz@redhat.com>
  */
 
-#include <config.h>
+#include "config.h"
 #include "gmount.h"
 #include "gvolume.h"
+#include "gasyncresult.h"
 #include "gsimpleasyncresult.h"
+#include "gioerror.h"
 #include "glibintl.h"
 
 #include "gioalias.h"
@@ -78,11 +80,11 @@ static void g_volume_class_init (gpointer g_class,
 GType
 g_volume_get_type (void)
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static GType volume_type = 0;
 
-  if (g_once_init_enter (&g_define_type_id__volatile))
+  if (! volume_type)
     {
-      const GTypeInfo volume_info =
+      static const GTypeInfo volume_info =
       {
         sizeof (GVolumeIface), /* class_size */
 	g_volume_base_init,   /* base_init */
@@ -94,16 +96,15 @@ g_volume_get_type (void)
 	0,              /* n_preallocs */
 	NULL
       };
-      GType g_define_type_id =
+
+      volume_type =
 	g_type_register_static (G_TYPE_INTERFACE, I_("GVolume"),
 				&volume_info, 0);
 
-      g_type_interface_add_prerequisite (g_define_type_id, G_TYPE_OBJECT);
-
-      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
+      g_type_interface_add_prerequisite (volume_type, G_TYPE_OBJECT);
     }
 
-  return g_define_type_id__volatile;
+  return volume_type;
 }
 
 static void
