@@ -1,3 +1,5 @@
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
+
 /* GIO - GLib Input, Output and Streaming Library
  * 
  * Copyright (C) 2006-2007 Red Hat, Inc.
@@ -28,10 +30,7 @@
 #ifndef __G_VOLUME_MONITOR_H__
 #define __G_VOLUME_MONITOR_H__
 
-#include <glib-object.h>
-#include <gio/gmount.h>
-#include <gio/gvolume.h>
-#include <gio/gdrive.h>
+#include <gio/giotypes.h>
 
 G_BEGIN_DECLS
 
@@ -42,6 +41,12 @@ G_BEGIN_DECLS
 #define G_IS_VOLUME_MONITOR(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), G_TYPE_VOLUME_MONITOR))
 #define G_IS_VOLUME_MONITOR_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), G_TYPE_VOLUME_MONITOR))
 
+/**
+ * G_VOLUME_MONITOR_EXTENSION_POINT_NAME:
+ *
+ * Extension point for volume monitor functionality.
+ * See <link linkend="gio-extension-points">Extending GIO</link>.
+ */
 #define G_VOLUME_MONITOR_EXTENSION_POINT_NAME "gio-volume-monitor"
 
 /**
@@ -50,7 +55,6 @@ G_BEGIN_DECLS
  *
  * A Volume Monitor that watches for volume events.
  **/
-typedef struct _GVolumeMonitor GVolumeMonitor;
 typedef struct _GVolumeMonitorClass GVolumeMonitorClass;
 
 struct _GVolumeMonitor {
@@ -103,8 +107,9 @@ struct _GVolumeMonitorClass {
                                      const char      *uuid);
 
 
-  GVolume * (*adopt_orphan_mount)   (GMount          *mount);
-
+  /* These arguments are unfortunately backwards by mistake (bug #520169) */
+  GVolume * (*adopt_orphan_mount)   (GMount          *mount,
+                                     GVolumeMonitor  *volume_monitor);
   
   /*< private >*/
   /* Padding for future expansion */
