@@ -2922,8 +2922,11 @@ _g_dgettext_should_translate (void)
 
       const char *default_domain     = textdomain (NULL);
       const char *translator_comment = gettext ("");
+#ifndef G_OS_WIN32
       const char *translate_locale   = setlocale (LC_MESSAGES, NULL);
-
+#else
+      const char *translate_locale   = g_win32_getlocale ();
+#endif
       /* We should NOT translate only if all the following hold:
        *   - user has called textdomain() and set textdomain to non-default
        *   - default domain has no translations
